==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/types/EmailAddressList.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * Copyright 2020 Tridium, Inc. All Rights Reserved.
 */

/**
 * API Status: **Private**
 * @module nmodule/email/rc/types/EmailAddressList
 */

define(['baja!', 'nmodule/email/rc/types/EmailAddress'], function (baja, EmailAddress) {
  "use strict";

  /**
   * Representation of a `email:EmailAddressList`.
   * @alias module:nmodule/email/rc/type/EmailAddressList
   */
  var EmailAddressList = /*#__PURE__*/function (_baja$Simple) {
    function EmailAddressList(addresses) {
      var _this;
      _classCallCheck(this, EmailAddressList);
      _this = _callSuper(this, EmailAddressList, [addresses]);
      _this.$addresses = addresses || [];
      return _this;
    }
    _inherits(EmailAddressList, _baja$Simple);
    return _createClass(EmailAddressList, [{
      key: "isNull",
      value:
      /**
       * Determins whether or not the email address list is null.
       *
       * @returns {boolean}
       */
      function isNull() {
        return this === EmailAddressList.NULL || !this.$addresses || !this.$addresses.length;
      }

      /**
       * Creates an EmailAddressList object from the provided encoding.
       *
       * @param {string} str
       * @retrusn{module:nmodule/email/rc/type/EmailAddressList}
       */
    }, {
      key: "decodeFromString",
      value: function decodeFromString(str) {
        if (!str) {
          return EmailAddressList.NULL;
        }
        var addresses = str.split(";").map(function (emailStr) {
          return EmailAddress.DEFAULT.decodeFromString(emailStr);
        });
        return new EmailAddressList(addresses);
      }

      /**
       * Encodes the email address list to a string with a semicolon delimiter
       * between the individual address encodings.
       *
       * @returns {string}
       */
    }, {
      key: "encodeToString",
      value: function encodeToString() {
        if (this.isNull()) {
          return "";
        }
        return this.$addresses.reduce(function (encoding, currentValue, currentIndex) {
          var delimiter = currentIndex > 0 ? ";" : "";
          return encoding + delimiter + currentValue.encodeToString();
        }, "");
      }

      /**
       * Gets a copy of the address in the email address list
       *
       * @returns {Array.<module:nmodule/email/rc/type/EmailAddress>}
       */
    }, {
      key: "getAddresses",
      value: function getAddresses() {
        return this.$addresses.slice(0);
      }
    }], [{
      key: "make",
      value: function make(addresses) {
        return new EmailAddressList(addresses);
      }
    }]);
  }(baja.Simple);
  EmailAddressList.DEFAULT = EmailAddressList.make([]);
  EmailAddressList.NULL = EmailAddressList.DEFAULT;
  return EmailAddressList;
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/types/EmailAddressList.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * Copyright 2020 Tridium, Inc. All Rights Reserved.
 */

/**
 * API Status: **Private**
 * @module nmodule/email/rc/types/EmailAddressList
 */

define(['baja!', 'nmodule/email/rc/types/EmailAddress'], function (baja, EmailAddress) {
  "use strict";

  /**
   * Representation of a `email:EmailAddressList`.
   * @alias module:nmodule/email/rc/type/EmailAddressList
   */
  var EmailAddressList = /*#__PURE__*/function (_baja$Simple) {
    function EmailAddressList(addresses) {
      var _this;
      _classCallCheck(this, EmailAddressList);
      _this = _callSuper(this, EmailAddressList, [addresses]);
      _this.$addresses = addresses || [];
      return _this;
    }
    _inherits(EmailAddressList, _baja$Simple);
    return _createClass(EmailAddressList, [{
      key: "make",
      value: function make() {
        return EmailAddressList.make.apply(EmailAddressList, arguments);
      }

      /**
       * Determines whether or not the email address list is null.
       *
       * @returns {boolean}
       */
    }, {
      key: "isNull",
      value: function isNull() {
        return this === EmailAddressList.NULL || !this.$addresses || !this.$addresses.length;
      }

      /**
       * Creates an EmailAddressList object from the provided encoding.
       *
       * @param {string} str
       * @returns {module:nmodule/email/rc/type/EmailAddressList}
       */
    }, {
      key: "decodeFromString",
      value: function decodeFromString(str) {
        if (!str) {
          return EmailAddressList.NULL;
        }
        var addresses = str.split(";").map(function (emailStr) {
          return EmailAddress.DEFAULT.decodeFromString(emailStr);
        });
        return new EmailAddressList(addresses);
      }

      /**
       * Encodes the email address list to a string with a semicolon delimiter
       * between the individual address encodings.
       *
       * @returns {string}
       */
    }, {
      key: "encodeToString",
      value: function encodeToString() {
        if (this.isNull()) {
          return "";
        }
        return this.$addresses.reduce(function (encoding, currentValue, currentIndex) {
          var delimiter = currentIndex > 0 ? ";" : "";
          return encoding + delimiter + currentValue.encodeToString();
        }, "");
      }

      /**
       * Gets a copy of the address in the email address list
       *
       * @returns {Array.<module:nmodule/email/rc/type/EmailAddress>}
       */
    }, {
      key: "getAddresses",
      value: function getAddresses() {
        return this.$addresses.slice(0);
      }
    }], [{
      key: "make",
      value: function make(addresses) {
        return new EmailAddressList(addresses);
      }
    }]);
  }(baja.Simple);
  EmailAddressList.DEFAULT = EmailAddressList.make([]);
  EmailAddressList.NULL = EmailAddressList.DEFAULT;
  return EmailAddressList;
});
